@@ -73,9 +73,9 @@ else:
         n_shiyan=int(input())
         print("请输入对照组组人数")
         n_duizhao=int(input())
-        print("请输入实验组二项分布事件发生的概率")
+        print("请输入实验组二项分布事件发生的概率,小数，比如:0.154")
         p_shiyan=float(input())
-        print("请输入对照组二项分布事件发生的概率")
+        print("请输入对照组二项分布事件发生的概率,小数，比如:0.154")
         p_duizhao=float(input())
        
         #计算z-soce,二项分布
@@ -89,11 +89,11 @@ else:
 
         if 1.96 <= z_score<2.58:
             result='一般显著'
-            Confidence_interval_top=(p_shiyan-p_duizhao)+1.96*fenmu
-            Confidence_interval_down=(p_shiyan-p_duizhao)-1.96*fenmu
+            Confidence_interval_top=round((p_shiyan-p_duizhao)+1.96*fenmu,4)
+            Confidence_interval_down=round((p_shiyan-p_duizhao)-1.96*fenmu,4)
             return "实验结果:{0},区间为:[{1},{2}]".format(result,Confidence_interval_down,Confidence_interval_top)
         if 2.58<=z_score:
             result='非常显著'
-            Confidence_interval_top=(p_shiyan-p_duizhao)+1.96*fenmu
-            Confidence_interval_down=(p_shiyan-p_duizhao)-1.96*fenmu
+            Confidence_interval_top=round((p_shiyan-p_duizhao)+2.58*fenmu,4)
+            Confidence_interval_down=round((p_shiyan-p_duizhao)-2.58*fenmu,4)
             return "实验结果:{0},区间为:[{1},{2}]".format(result,Confidence_interval_down,Confidence_interval_top)
